==> base-domain-0.0.3-20170427.042358-145-sources.jar: com/thebeastshop/scm/es/PsBrandVO.java <==
package com.thebeastshop.scm.es;

import java.util.Map;

import org.apache.commons.collections4.MapUtils;

import pers.richard.ormybatis.domain.core.AbstractDomain;

public class PsBrandVO extends AbstractDomain {

	private Long brandId; //品牌
	private String brandName;
    private String brandNameCN;
    private Long brandCountryId;
    private String brandCountryName;
    
    public PsBrandVO() {}
    
    public PsBrandVO(Map<String, Object> map) {
    	this.brandId = MapUtils.getLong(map, "brandId");
    	this.brandName= MapUtils.getString(map, "brandName"); 
    	this.brandNameCN= MapUtils.getString(map, "brandNameCN");
    	this.brandCountryId= MapUtils.getLong(map, "brandCountryId");
    	this.brandCountryName= MapUtils.getString(map, "brandCountryName");
    }
    
    public Long getBrandId() {
		return brandId;
	}
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}
	public String getBrandName() {
		return brandName;
	}
	public void setBrandName(String brandName) {
		this.brandName = brandName;
	}
	public String getBrandNameCN() {
		return brandNameCN;
	}
	public void setBrandNameCN(String brandNameCN) {
		this.brandNameCN = brandNameCN;
	}
	public Long getBrandCountryId() {
		return brandCountryId;
	}
	public void setBrandCountryId(Long brandCountryId) {
		this.brandCountryId = brandCountryId;
	}
	public String getBrandCountryName() {
		return brandCountryName;
	}
	public void setBrandCountryName(String brandCountryName) {
		this.brandCountryName = brandCountryName;
	}
	
	public boolean equals(PsBrandVO obj) {
		return this.getBrandId().equals(obj.getBrandId());
	}
	
}

==> base-domain-1.1.9-sources.jar: com/thebeastshop/scm/es/PsBrandVO.java <==
package com.thebeastshop.scm.es;

import java.util.Map;

import org.apache.commons.collections4.MapUtils;

import pers.richard.ormybatis.domain.core.AbstractDomain;

public class PsBrandVO extends AbstractDomain {

	private Long brandId; //品牌
	private String brandName;
    private String brandNameCN;
    private Long brandCountryId;
    private String brandCountryName;
	private Long authLetter;
    
    public PsBrandVO() {}
    
    public PsBrandVO(Map<String, Object> map) {
    	this.brandId = MapUtils.getLong(map, "brandId");
    	this.brandName= MapUtils.getString(map, "brandName"); 
    	this.brandNameCN= MapUtils.getString(map, "brandNameCN");
    	this.brandCountryId= MapUtils.getLong(map, "brandCountryId");
    	this.brandCountryName= MapUtils.getString(map, "brandCountryName");
		this.authLetter= MapUtils.getLong(map, "authLetter");
    }
    
    public Long getBrandId() {
		return brandId;
	}
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}
	public String getBrandName() {
		return brandName;
	}
	public void setBrandName(String brandName) {
		this.brandName = brandName;
	}
	public String getBrandNameCN() {
		return brandNameCN;
	}
	public void setBrandNameCN(String brandNameCN) {
		this.brandNameCN = brandNameCN;
	}
	public Long getBrandCountryId() {
		return brandCountryId;
	}
	public void setBrandCountryId(Long brandCountryId) {
		this.brandCountryId = brandCountryId;
	}
	public String getBrandCountryName() {
		return brandCountryName;
	}
	public void setBrandCountryName(String brandCountryName) {
		this.brandCountryName = brandCountryName;
	}
	
	public boolean equals(PsBrandVO obj) {
		return this.getBrandId().equals(obj.getBrandId());
	}

	public Long getAuthLetter() {
		return authLetter;
	}

	public void setAuthLetter(Long authLetter) {
		this.authLetter = authLetter;
	}
}
